@@ -1,11 +1,11 @@
 /*
   Copyright (C) 2003 GraphicsMagick Group
   Copyright (C) 2002 ImageMagick Studio
- 
+
   This program is covered by multiple licenses, which are described in
   Copyright.txt. You should have received a copy of Copyright.txt with this
   package; otherwise see http://www.graphicsmagick.org/www/Copyright.html.
- 
+
   Methods to Get/Set/Destroy Image Text Attributes.
 */
 #ifndef _MAGICK_ATTRIBUTE_H
@@ -46,6 +46,10 @@ extern MagickExport MagickPassFail
 extern MagickExport void
   DestroyImageAttributes(Image *image);
 
+#if defined(MAGICK_IMPLEMENTATION)
+#  include "magick/attribute-private.h"
+#endif /* defined(MAGICK_IMPLEMENTATION) */
+
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
