@@ -1,18 +1,11 @@
 /*
-  Copyright (C) 2003 - 2013 GraphicsMagick Group
- 
+  Copyright (C) 2012-2018 GraphicsMagick Group
+
   This program is covered by multiple licenses, which are described in
   Copyright.txt. You should have received a copy of Copyright.txt with this
   package; otherwise see http://www.graphicsmagick.org/www/Copyright.html.
 
   Library symbol name-scoping support.
-
-  Obtained via:
-
-  nm -p magick/.libs/libGraphicsMagick.a | grep ' T ' | egrep -vi '(Gm)|(lt_)' | \
-     egrep -v '(MagickError)|(MagickFatalError)|(MagickWarning)|(ThrowException)' | \
-     awk '{ printf("#define %s Gm%s\n", $3, $3); }' | sort
-
 */
 
 #if !defined(_MAGICK_SYMBOLS_H)
@@ -74,7 +67,6 @@
 #define AttachBlob GmAttachBlob
 #define AutoOrientImage GmAutoOrientImage
 #define AverageImages GmAverageImages
-#define BackgroundColor GmBackgroundColor
 #define Base64Decode GmBase64Decode
 #define Base64Encode GmBase64Encode
 #define BenchmarkImageCommand GmBenchmarkImageCommand
@@ -87,7 +79,6 @@
 #define BlobWriteByteHook GmBlobWriteByteHook
 #define BlurImage GmBlurImage
 #define BlurImageChannel GmBlurImageChannel
-#define BorderColor GmBorderColor
 #define BorderImage GmBorderImage
 #define CatchException GmCatchException
 #define CatchImageException GmCatchImageException
@@ -96,6 +87,7 @@
 #define ChannelThresholdImage GmChannelThresholdImage
 #define ChannelTypeToString GmChannelTypeToString
 #define CharcoalImage GmCharcoalImage
+#define CheckImagePixelLimits GmCheckImagePixelLimits
 #define ChopImage GmChopImage
 #define ClassTypeToString GmClassTypeToString
 #define ClipImage GmClipImage
@@ -121,7 +113,9 @@
 #define CompositeImage GmCompositeImage
 #define CompositeImageCommand GmCompositeImageCommand
 #define CompositeImageRegion GmCompositeImageRegion
+#define CompositeMaskImage GmCompositeMaskImage
 #define CompositeOperatorToString GmCompositeOperatorToString
+#define CompositePathImage GmCompositePathImage
 #define CompressImageColormap GmCompressImageColormap
 #define CompressionTypeToString GmCompressionTypeToString
 #define ConcatenateString GmConcatenateString
@@ -137,12 +131,8 @@
 #define CopyException GmCopyException
 #define CropImage GmCropImage
 #define CycleColormapImage GmCycleColormapImage
-#define DCM_SetRescaling GmDCM_SetRescaling
 #define DeallocateImageProfileIterator GmDeallocateImageProfileIterator
 #define DeconstructImages GmDeconstructImages
-#define DefaultTileFrame GmDefaultTileFrame
-#define DefaultTileGeometry GmDefaultTileGeometry
-#define DefaultTileLabel GmDefaultTileLabel
 #define DefineClientName GmDefineClientName
 #define DefineClientPathAndName GmDefineClientPathAndName
 #define DeleteImageFromList GmDeleteImageFromList
@@ -166,6 +156,9 @@
 #define DestroyLogInfo GmDestroyLogInfo
 #define DestroyMagicInfo GmDestroyMagicInfo
 #define DestroyMagick GmDestroyMagick
+#define DestroyMagickExceptionHandling GmDestroyMagickExceptionHandling
+#define DestroyMagickModules GmDestroyMagickModules
+#define DestroyMagickMonitor GmDestroyMagickMonitor
 #define DestroyMagickRandomGenerator GmDestroyMagickRandomGenerator
 #define DestroyMagickRegistry GmDestroyMagickRegistry
 #define DestroyMagickResources GmDestroyMagickResources
@@ -179,6 +172,7 @@
 #define DestroyTypeInfo GmDestroyTypeInfo
 #define DetachBlob GmDetachBlob
 #define DifferenceImage GmDifferenceImage
+#define DisassociateBlob GmDisassociateBlob
 #define DispatchImage GmDispatchImage
 #define DisplayImageCommand GmDisplayImageCommand
 #define DisplayImages GmDisplayImages
@@ -193,6 +187,7 @@
 #define DrawColor GmDrawColor
 #define DrawComment GmDrawComment
 #define DrawComposite GmDrawComposite
+#define DrawCompositeMask GmDrawCompositeMask
 #define DrawDestroyContext GmDrawDestroyContext
 #define DrawEllipse GmDrawEllipse
 #define DrawGetClipPath GmDrawGetClipPath
@@ -222,6 +217,8 @@
 #define DrawGetTextEncoding GmDrawGetTextEncoding
 #define DrawGetTextUnderColor GmDrawGetTextUnderColor
 #define DrawImage GmDrawImage
+#define DrawInfoGetClipPath GmDrawInfoGetClipPath
+#define DrawInfoGetCompositePath GmDrawInfoGetCompositePath
 #define DrawLine GmDrawLine
 #define DrawMatte GmDrawMatte
 #define DrawPathClose GmDrawPathClose
@@ -319,7 +316,6 @@
 #define FlattenImages GmFlattenImages
 #define FlipImage GmFlipImage
 #define FlopImage GmFlopImage
-#define ForegroundColor GmForegroundColor
 #define FormatSize GmFormatSize
 #define FormatString GmFormatString
 #define FormatStringList GmFormatStringList
@@ -331,6 +327,7 @@
 #define GenerateDifferentialNoise GmGenerateDifferentialNoise
 #define GenerateNoise GmGenerateNoise
 #define GetBlobFileHandle GmGetBlobFileHandle
+#define GetBlobFirstErrno GmGetBlobFirstErrno
 #define GetBlobInfo GmGetBlobInfo
 #define GetBlobIsOpen GmGetBlobIsOpen
 #define GetBlobSize GmGetBlobSize
@@ -370,6 +367,7 @@
 #define GetImageCharacteristics GmGetImageCharacteristics
 #define GetImageClipMask GmGetImageClipMask
 #define GetImageClippingPathAttribute GmGetImageClippingPathAttribute
+#define GetImageCompositeMask GmGetImageCompositeMask
 #define GetImageDepth GmGetImageDepth
 #define GetImageDistortion GmGetImageDistortion
 #define GetImageException GmGetImageException
@@ -432,6 +430,7 @@
 #define GetUserTime GmGetUserTime
 #define GlobExpression GmGlobExpression
 #define GradientImage GmGradientImage
+#define GravityTypeToString GmGravityTypeToString
 #define GrayscalePseudoClassImage GmGrayscalePseudoClassImage
 #define HSLTransform GmHSLTransform
 #define HWBTransform GmHWBTransform
@@ -443,6 +442,8 @@
 #define Hull GmHull
 #define IdentifyImageCommand GmIdentifyImageCommand
 #define IdentityAffine GmIdentityAffine
+#define ImageGetClipMask GmImageGetClipMask
+#define ImageGetCompositeMask GmImageGetCompositeMask
 #define ImageListToArray GmImageListToArray
 #define ImageToBlob GmImageToBlob
 #define ImageToFile GmImageToFile
@@ -462,14 +463,17 @@
 #define InitializeDifferenceImageOptions GmInitializeDifferenceImageOptions
 #define InitializeDifferenceStatistics GmInitializeDifferenceStatistics
 #define InitializeLogInfo GmInitializeLogInfo
+#define InitializeLogInfoPost GmInitializeLogInfoPost
 #define InitializeMagicInfo GmInitializeMagicInfo
 #define InitializeMagick GmInitializeMagick
-#define InitializeMagickClientPathAndName GmInitializeMagickClientPathAndName
+#define InitializeMagickEx GmInitializeMagickEx
+#define InitializeMagickExceptionHandling GmInitializeMagickExceptionHandling
+#define InitializeMagickModules GmInitializeMagickModules
+#define InitializeMagickMonitor GmInitializeMagickMonitor
 #define InitializeMagickRandomGenerator GmInitializeMagickRandomGenerator
 #define InitializeMagickRandomKernel GmInitializeMagickRandomKernel
 #define InitializeMagickRegistry GmInitializeMagickRegistry
 #define InitializeMagickResources GmInitializeMagickResources
-#define InitializeMagickSignalHandlers GmInitializeMagickSignalHandlers
 #define InitializePixelIteratorOptions GmInitializePixelIteratorOptions
 #define InitializeSemaphore GmInitializeSemaphore
 #define InitializeTemporaryFiles GmInitializeTemporaryFiles
@@ -517,13 +521,15 @@
 #define LocaleNCompare GmLocaleNCompare
 #define LocaleUpper GmLocaleUpper
 #define LockSemaphoreInfo GmLockSemaphoreInfo
-#define LogMagickEvent GmLogMagickEvent
-#define LogMagickEventList GmLogMagickEventList
-#define MatteColor GmMatteColor
 #define MSBOrderLong GmMSBOrderLong
 #define MSBOrderShort GmMSBOrderShort
 #define MagickAllocFunctions GmMagickAllocFunctions
 #define MagickArraySize GmMagickArraySize
+#define MagickAtoFChk GmMagickAtoFChk
+#define MagickAtoIChk GmMagickAtoIChk
+#define MagickAtoLChk GmMagickAtoLChk
+#define MagickAtoUIChk GmMagickAtoUIChk
+#define MagickAtoULChk GmMagickAtoULChk
 #define MagickBitStreamInitializeRead GmMagickBitStreamInitializeRead
 #define MagickBitStreamInitializeWrite GmMagickBitStreamInitializeWrite
 #define MagickBitStreamMSBRead GmMagickBitStreamMSBRead
@@ -535,13 +541,20 @@
 #define MagickConstrainColormapIndex GmMagickConstrainColormapIndex
 #define MagickCreateDirectoryPath GmMagickCreateDirectoryPath
 #define MagickDestroyCommandInfo GmMagickDestroyCommandInfo
+#define MagickDoubleToLong GmMagickDoubleToLong
 #define MagickFindRawImageMinMax GmMagickFindRawImageMinMax
+#define MagickFmax GmMagickFmax
+#define MagickFmin GmMagickFmin
+#define MagickFormatString GmMagickFormatString
+#define MagickFormatStringList GmMagickFormatStringList
 #define MagickFree GmMagickFree
 #define MagickFreeAligned GmMagickFreeAligned
 #define MagickGetBitRevTable GmMagickGetBitRevTable
+#define MagickGetFileAttributes GmMagickGetFileAttributes
 #define MagickGetFileSystemBlockSize GmMagickGetFileSystemBlockSize
 #define MagickGetMMUPageSize GmMagickGetMMUPageSize
 #define MagickGetQuantumSamplesPerPixel GmMagickGetQuantumSamplesPerPixel
+#define MagickGetToken GmMagickGetToken
 #define MagickInitializeCommandInfo GmMagickInitializeCommandInfo
 #define MagickIsTrue GmMagickIsTrue
 #define MagickMalloc GmMagickMalloc
@@ -568,6 +581,7 @@
 #define MagickMapIterateToFront GmMagickMapIterateToFront
 #define MagickMapRemoveEntry GmMagickMapRemoveEntry
 #define MagickMonitor GmMagickMonitor
+#define MagickMonitorActive GmMagickMonitorActive
 #define MagickMonitorFormatted GmMagickMonitorFormatted
 #define MagickRandNewSeed GmMagickRandNewSeed
 #define MagickRandReentrant GmMagickRandReentrant
@@ -577,9 +591,11 @@
 #define MagickReverseBits GmMagickReverseBits
 #define MagickSceneFileName GmMagickSceneFileName
 #define MagickSetConfirmAccessHandler GmMagickSetConfirmAccessHandler
+#define MagickSetFileAttributes GmMagickSetFileAttributes
 #define MagickSetFileSystemBlockSize GmMagickSetFileSystemBlockSize
 #define MagickSizeStrToInt64 GmMagickSizeStrToInt64
 #define MagickSpawnVP GmMagickSpawnVP
+#define MagickStripSpacesFromString GmMagickStripSpacesFromString
 #define MagickStrlCat GmMagickStrlCat
 #define MagickStrlCpy GmMagickStrlCpy
 #define MagickStrlCpyTrunc GmMagickStrlCpyTrunc
@@ -669,6 +685,7 @@
 #define MagickXSetWindows GmMagickXSetWindows
 #define MagickXSignalHandler GmMagickXSignalHandler
 #define MagickXTextViewWidget GmMagickXTextViewWidget
+#define MagickXTextViewWidgetNDL GmMagickXTextViewWidgetNDL
 #define MagickXUserPreferences GmMagickXUserPreferences
 #define MagickXWarning GmMagickXWarning
 #define MagickXWindowByID GmMagickXWindowByID
@@ -705,10 +722,13 @@
 #define OpaqueImage GmOpaqueImage
 #define OpenBlob GmOpenBlob
 #define OpenCacheView GmOpenCacheView
+#define OpenModule GmOpenModule
+#define OpenModules GmOpenModules
 #define OrderedDitherImage GmOrderedDitherImage
 #define OrientationTypeToString GmOrientationTypeToString
 #define PackbitsEncode2Image GmPackbitsEncode2Image
 #define PackbitsEncodeImage GmPackbitsEncodeImage
+#define PanicDestroyMagick GmPanicDestroyMagick
 #define PersistCache GmPersistCache
 #define PingBlob GmPingBlob
 #define PingImage GmPingImage
@@ -717,15 +737,15 @@
 #define PixelIterateDualRead GmPixelIterateDualRead
 #define PixelIterateMonoModify GmPixelIterateMonoModify
 #define PixelIterateMonoRead GmPixelIterateMonoRead
+#define PixelIterateMonoSet GmPixelIterateMonoSet
 #define PixelIterateTripleModify GmPixelIterateTripleModify
 #define PixelIterateTripleNew GmPixelIterateTripleNew
 #define PlasmaImage GmPlasmaImage
 #define PopImagePixels GmPopImagePixels
 #define PrependImageToList GmPrependImageToList
 #define ProfileImage GmProfileImage
-#define PSDensityGeometry GmPSDensityGeometry
-#define PSPageGeometry GmPSPageGeometry
 #define PurgeTemporaryFiles GmPurgeTemporaryFiles
+#define PurgeTemporaryFilesAsyncSafe GmPurgeTemporaryFilesAsyncSafe
 #define PushImagePixels GmPushImagePixels
 #define QuantizeImage GmQuantizeImage
 #define QuantizeImages GmQuantizeImages
@@ -743,7 +763,6 @@
 #define ReacquireMemory GmReacquireMemory
 #define ReadBlob GmReadBlob
 #define ReadBlobByte GmReadBlobByte
-#define ReadBlobByteFromBuffer GmReadBlobByteFromBuffer
 #define ReadBlobLSBDouble GmReadBlobLSBDouble
 #define ReadBlobLSBDoubles GmReadBlobLSBDoubles
 #define ReadBlobLSBFloat GmReadBlobLSBFloat
@@ -751,8 +770,9 @@
 #define ReadBlobLSBLong GmReadBlobLSBLong
 #define ReadBlobLSBLongs GmReadBlobLSBLongs
 #define ReadBlobLSBShort GmReadBlobLSBShort
-#define ReadBlobLSBShortFromBuffer GmReadBlobLSBShortFromBuffer
 #define ReadBlobLSBShorts GmReadBlobLSBShorts
+#define ReadBlobLSBSignedLong GmReadBlobLSBSignedLong
+#define ReadBlobLSBSignedShort GmReadBlobLSBSignedShort
 #define ReadBlobMSBDouble GmReadBlobMSBDouble
 #define ReadBlobMSBDoubles GmReadBlobMSBDoubles
 #define ReadBlobMSBFloat GmReadBlobMSBFloat
@@ -761,18 +781,21 @@
 #define ReadBlobMSBLongs GmReadBlobMSBLongs
 #define ReadBlobMSBShort GmReadBlobMSBShort
 #define ReadBlobMSBShorts GmReadBlobMSBShorts
+#define ReadBlobMSBSignedLong GmReadBlobMSBSignedLong
+#define ReadBlobMSBSignedShort GmReadBlobMSBSignedShort
 #define ReadBlobString GmReadBlobString
 #define ReadBlobZC GmReadBlobZC
 #define ReadImage GmReadImage
 #define ReadInlineImage GmReadInlineImage
+#define ReallocateImageColormap GmReallocateImageColormap
 #define ReduceNoiseImage GmReduceNoiseImage
 #define ReferenceBlob GmReferenceBlob
 #define ReferenceCache GmReferenceCache
 #define ReferenceImage GmReferenceImage
 #define RegisterARTImage GmRegisterARTImage
-#define RegisterAVIImage GmRegisterAVIImage
 #define RegisterAVSImage GmRegisterAVSImage
 #define RegisterBMPImage GmRegisterBMPImage
+#define RegisterBRAILLEImage GmRegisterBRAILLEImage
 #define RegisterCALSImage GmRegisterCALSImage
 #define RegisterCAPTIONImage GmRegisterCAPTIONImage
 #define RegisterCINEONImage GmRegisterCINEONImage
@@ -794,6 +817,7 @@
 #define RegisterICONImage GmRegisterICONImage
 #define RegisterIDENTITYImage GmRegisterIDENTITYImage
 #define RegisterINFOImage GmRegisterINFOImage
+#define RegisterJBIGImage GmRegisterJBIGImage
 #define RegisterJNXImage GmRegisterJNXImage
 #define RegisterJP2Image GmRegisterJP2Image
 #define RegisterJPEGImage GmRegisterJPEGImage
@@ -830,7 +854,6 @@
 #define RegisterPREVIEWImage GmRegisterPREVIEWImage
 #define RegisterPS2Image GmRegisterPS2Image
 #define RegisterPS3Image GmRegisterPS3Image
-#define RegisterPSDImage GmRegisterPSDImage
 #define RegisterPSImage GmRegisterPSImage
 #define RegisterPWPImage GmRegisterPWPImage
 #define RegisterRGBImage GmRegisterRGBImage
@@ -857,6 +880,7 @@
 #define RegisterVIDImage GmRegisterVIDImage
 #define RegisterVIFFImage GmRegisterVIFFImage
 #define RegisterWBMPImage GmRegisterWBMPImage
+#define RegisterWEBPImage GmRegisterWEBPImage
 #define RegisterWMFImage GmRegisterWMFImage
 #define RegisterWPGImage GmRegisterWPGImage
 #define RegisterXBMImage GmRegisterXBMImage
@@ -875,13 +899,13 @@
 #define ResetTimer GmResetTimer
 #define ResizeFilterToString GmResizeFilterToString
 #define ResizeImage GmResizeImage
+#define ResolutionTypeToString GmResolutionTypeToString
 #define ReverseImageList GmReverseImageList
 #define RollImage GmRollImage
 #define RotateImage GmRotateImage
 #define SampleImage GmSampleImage
 #define ScaleImage GmScaleImage
 #define SeekBlob GmSeekBlob
-#define SegmentImage GmSegmentImage
 #define SetBlobClosable GmSetBlobClosable
 #define SetBlobTemporary GmSetBlobTemporary
 #define SetCacheView GmSetCacheView
@@ -900,7 +924,9 @@
 #define SetImageClipMask GmSetImageClipMask
 #define SetImageColor GmSetImageColor
 #define SetImageColorRegion GmSetImageColorRegion
+#define SetImageCompositeMask GmSetImageCompositeMask
 #define SetImageDepth GmSetImageDepth
+#define SetImageEx GmSetImageEx
 #define SetImageInfo GmSetImageInfo
 #define SetImageOpacity GmSetImageOpacity
 #define SetImagePixels GmSetImagePixels
@@ -908,6 +934,12 @@
 #define SetImageProfile GmSetImageProfile
 #define SetImageType GmSetImageType
 #define SetImageVirtualPixelMethod GmSetImageVirtualPixelMethod
+#define SetLogDefaultEventType GmSetLogDefaultEventType
+#define SetLogDefaultFileName GmSetLogDefaultFileName
+#define SetLogDefaultFormat GmSetLogDefaultFormat
+#define SetLogDefaultGenerations GmSetLogDefaultGenerations
+#define SetLogDefaultLimit GmSetLogDefaultLimit
+#define SetLogDefaultOutputType GmSetLogDefaultOutputType
 #define SetLogEventMask GmSetLogEventMask
 #define SetLogFormat GmSetLogFormat
 #define SetMagickInfo GmSetMagickInfo
@@ -926,8 +958,10 @@
 #define SpliceImageIntoList GmSpliceImageIntoList
 #define SplitImageList GmSplitImageList
 #define SpreadImage GmSpreadImage
+#define StartTimer GmStartTimer
 #define SteganoImage GmSteganoImage
 #define StereoImage GmStereoImage
+#define StopTimer GmStopTimer
 #define StorageTypeToString GmStorageTypeToString
 #define StretchTypeToString GmStretchTypeToString
 #define StringToArgv GmStringToArgv
@@ -945,8 +979,10 @@
 #define StringToList GmStringToList
 #define StringToMetricType GmStringToMetricType
 #define StringToNoiseType GmStringToNoiseType
+#define StringToOrientationType GmStringToOrientationType
 #define StringToPreviewType GmStringToPreviewType
 #define StringToQuantumOperator GmStringToQuantumOperator
+#define StringToResolutionType GmStringToResolutionType
 #define StringToResourceType GmStringToResourceType
 #define StringToVirtualPixelMethod GmStringToVirtualPixelMethod
 #define Strip GmStrip
@@ -980,9 +1016,9 @@
 #define UnlockSemaphoreInfo GmUnlockSemaphoreInfo
 #define UnmapBlob GmUnmapBlob
 #define UnregisterARTImage GmUnregisterARTImage
-#define UnregisterAVIImage GmUnregisterAVIImage
 #define UnregisterAVSImage GmUnregisterAVSImage
 #define UnregisterBMPImage GmUnregisterBMPImage
+#define UnregisterBRAILLEImage GmUnregisterBRAILLEImage
 #define UnregisterCALSImage GmUnregisterCALSImage
 #define UnregisterCAPTIONImage GmUnregisterCAPTIONImage
 #define UnregisterCINEONImage GmUnregisterCINEONImage
@@ -1004,6 +1040,7 @@
 #define UnregisterICONImage GmUnregisterICONImage
 #define UnregisterIDENTITYImage GmUnregisterIDENTITYImage
 #define UnregisterINFOImage GmUnregisterINFOImage
+#define UnregisterJBIGImage GmUnregisterJBIGImage
 #define UnregisterJNXImage GmUnregisterJNXImage
 #define UnregisterJP2Image GmUnregisterJP2Image
 #define UnregisterJPEGImage GmUnregisterJPEGImage
@@ -1040,7 +1077,6 @@
 #define UnregisterPREVIEWImage GmUnregisterPREVIEWImage
 #define UnregisterPS2Image GmUnregisterPS2Image
 #define UnregisterPS3Image GmUnregisterPS3Image
-#define UnregisterPSDImage GmUnregisterPSDImage
 #define UnregisterPSImage GmUnregisterPSImage
 #define UnregisterPWPImage GmUnregisterPWPImage
 #define UnregisterRGBImage GmUnregisterRGBImage
@@ -1067,6 +1103,7 @@
 #define UnregisterVIDImage GmUnregisterVIDImage
 #define UnregisterVIFFImage GmUnregisterVIFFImage
 #define UnregisterWBMPImage GmUnregisterWBMPImage
+#define UnregisterWEBPImage GmUnregisterWEBPImage
 #define UnregisterWMFImage GmUnregisterWMFImage
 #define UnregisterWPGImage GmUnregisterWPGImage
 #define UnregisterXBMImage GmUnregisterXBMImage
@@ -1086,8 +1123,12 @@
 #define WriteBlobFile GmWriteBlobFile
 #define WriteBlobLSBLong GmWriteBlobLSBLong
 #define WriteBlobLSBShort GmWriteBlobLSBShort
+#define WriteBlobLSBSignedLong GmWriteBlobLSBSignedLong
+#define WriteBlobLSBSignedShort GmWriteBlobLSBSignedShort
 #define WriteBlobMSBLong GmWriteBlobMSBLong
 #define WriteBlobMSBShort GmWriteBlobMSBShort
+#define WriteBlobMSBSignedLong GmWriteBlobMSBSignedLong
+#define WriteBlobMSBSignedShort GmWriteBlobMSBSignedShort
 #define WriteBlobString GmWriteBlobString
 #define WriteBlobStringEOL GmWriteBlobStringEOL
 #define WriteBlobStringWithEOL GmWriteBlobStringWithEOL
